summaryrefslogtreecommitdiff
path: root/strings
diff options
context:
space:
mode:
authorthommay <thommay@13f79535-47bb-0310-9956-ffa450edef68>2002-11-20 03:50:23 +0000
committerthommay <thommay@13f79535-47bb-0310-9956-ffa450edef68>2002-11-20 03:50:23 +0000
commit96a516ce915baab6aeac8564383d7203def7ca42 (patch)
tree970704b99664fde6f1803a70c4287a9326c2b7c4 /strings
parentf50ebd72d64ef2df0165d62d139dbfb0b70c3b4d (diff)
downloadlibapr-96a516ce915baab6aeac8564383d7203def7ca42.tar.gz
*) Renames done (deprecated functions wrapped):
apr_filename_of_pathname -> apr_filepath_name_get apr_get_groupid -> apr_gid_get apr_get_groupname -> apr_gid_name_get apr_compare_groups -> apr_gid_compare apr_parse_addr_port -> apr_port_addr_parse apr_shutdown -> apr_socket_shutdown apr_bind -> apr_socket_bind apr_listen -> apr_socket_listen apr_accept -> apr_socket_accept apr_connect -> apr_socket_connect apr_send -> apr_socket_send apr_sendv -> apr_socket_sendv apr_sendto -> apr_socket_sendto apr_implode_gmt -> apr_time_exp_gmt_get apr_get_home_directory -> apr_uid_homepath_get apr_get_userid -> apr_uid_get apr_current_userid -> apr_uid_current apr_compare_users -> apr_uid_compare apr_get_username -> apr_uid_name_get apr_recvfrom -> apr_socket_recvfrom apr_sendfile -> apr_socket_sendfile apr_recv -> apr_socket_recv git-svn-id: http://svn.apache.org/repos/asf/apr/apr/trunk@64043 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'strings')
-rw-r--r--strings/apr_cpystrn.c10
1 files changed, 8 insertions, 2 deletions
diff --git a/strings/apr_cpystrn.c b/strings/apr_cpystrn.c
index f99eb92fc..e9e9575ac 100644
--- a/strings/apr_cpystrn.c
+++ b/strings/apr_cpystrn.c
@@ -222,7 +222,7 @@ APR_DECLARE(apr_status_t) apr_tokenize_to_argv(const char *arg_str,
return APR_SUCCESS;
}
/* Filename_of_pathname returns the final element of the pathname.
* Using the current platform's filename syntax.
* "/foo/bar/gum" -> "gum"
* "/foo/bar/gum/" -> ""
@@ -232,7 +232,7 @@ APR_DECLARE(apr_status_t) apr_tokenize_to_argv(const char *arg_str,
* Corrected Win32 to accept "a/b\\stuff", "a:stuff"
*/
-APR_DECLARE(const char *) apr_filename_of_pathname(const char *pathname)
+APR_DECLARE(const char *) apr_filepath_name_get(const char *pathname)
{
const char path_separator = '/';
const char *s = strrchr(pathname, path_separator);
@@ -250,6 +250,12 @@ APR_DECLARE(const char *) apr_filename_of_pathname(const char *pathname)
return s ? ++s : pathname;
}
+/* deprecated */
+APR_DECLARE(const char *) apr_filename_of_pathname(const char *pathname)
+{
+ return apr_filepath_name_get(pathname);
+}
+
/* length of dest assumed >= length of src
* collapse in place (src == dest) is legal.
* returns terminating null ptr to dest string.
@@ -222,7 +222,7 @@ APR_DECLARE(apr_status_t) apr_tokenize_to_argv(const char *arg_str,
return APR_SUCCESS;
}
-/* Filename_of_pathname returns the final element of the pathname.
+/* Filepath_name_get returns the final element of the pathname.
* Using the current platform's filename syntax.
* "/foo/bar/gum" -> "gum"